@@ -1,20 +1,17 @@
 import copy
 import re
-import string
-import sys
 import warnings
 
 import numpy as np
 
 import pyfits
 from pyfits.util import (_str_to_num, _is_int, deprecated, maketrans,
-                         translate, _words_group, lazyproperty)
+                         translate, _words_group)
 from pyfits.verify import _Verify, _ErrList, VerifyError, VerifyWarning
 
 
 __all__ = ['Card', 'CardList', 'create_card', 'create_card_from_string',
-           'upper_key', 'createCard', 'createCardFromString', 'upperKey',
-           'Undefined']
+           'upper_key', 'Undefined']
 
 
 FIX_FP_TABLE = maketrans('de', 'DE')
@@ -29,7 +26,7 @@ VALUE_INDICATOR = '= '  # The standard FITS value indicator
 HIERARCH_VALUE_INDICATOR = '='  # HIERARCH cards may use a shortened indicator
 
 
-class Undefined:
+class Undefined(object):
     """Undefined value."""
 
     def __init__(self):
@@ -157,7 +154,7 @@ class CardList(list):
         """
         Return a list of the values of all cards in the `CardList`.
 
-        For ``RecordValuedKeywordCard`` objects, the value returned is
+        For `RecordValuedKeywordCard` objects, the value returned is
         the floating point value, exclusive of the
         ``field_specifier``.
         """
@@ -177,16 +174,17 @@ class CardList(list):
         useblanks : bool, optional
             Use any *extra* blank cards?
 
-            If ``useblanks`` is `True`, and if there are blank cards directly
-            before ``END``, it will use this space first, instead of appending
-            after these blank cards, so the total space will not increase.
-            When ``useblanks`` is `False`, the card will be appended at the
-            end, even if there are blank cards in front of ``END``.
+            If `useblanks` is `True`, and if there are blank cards
+            directly before ``END``, it will use this space first,
+            instead of appending after these blank cards, so the total
+            space will not increase.  When `useblanks` is `False`, the
+            card will be appended at the end, even if there are blank
+            cards in front of ``END``.
 
         bottom : bool, optional
-           If `False` the card will be appended after the last non-commentary
-           card.  If `True` the card will be appended after the last non-blank
-           card.
+           If `False` the card will be appended after the last
+           non-commentary card.  If `True` the card will be appended
+           after the last non-blank card.
         """
 
         self._header.append(card, useblanks=useblanks, bottom=bottom)
@@ -210,11 +208,12 @@ class CardList(list):
             The card to be inserted.
 
         useblanks : bool, optional
-            If ``useblanks`` is `True`, and if there are blank cards directly
-            before ``END``, it will use this space first, instead of appending
-            after these blank cards, so the total space will not increase.
-            When `useblanks` is `False`, the card will be appended at the end,
-            even if there are blank cards in front of ``END``.
+            If `useblanks` is `True`, and if there are blank cards
+            directly before ``END``, it will use this space first,
+            instead of appending after these blank cards, so the total
+            space will not increase.  When `useblanks` is `False`, the
+            card will be appended at the end, even if there are blank
+            cards in front of ``END``.
         """
 
         self._header.insert(idx, card, useblanks=useblanks)
@@ -245,7 +244,7 @@ class CardList(list):
         key : str or int
             The keyword name (a string) or the index (an integer).
 
-        backward : bool, optional
+        backward : bool, (optional)
             When `True`, search the index from the ``END``, i.e.,
             backward.
 
@@ -262,7 +261,7 @@ class CardList(list):
         else:
             raise KeyError('Illegal key data type %s' % type(key))
 
-    @deprecated('3.1', alternative='``header[<wildcard_pattern>]``')
+    @deprecated('3.1', alternative='`header[<wildcard_pattern>]`')
     def filter_list(self, key):
         """
         Construct a `CardList` that contains references to all of the cards in
@@ -276,18 +275,13 @@ class CardList(list):
 
         Returns
         -------
-        cardlist
+        cardlist :
             A `CardList` object containing references to all the
             requested cards.
         """
 
         return CardList(self._header[key])
 
-    # For API backwards-compatibility
-    @deprecated('3.0', alternative=':meth:`filter_list`', pending=False)
-    def filterList(self, key):
-        return self.filter_list(key)
-
     @deprecated('3.1', pending=False)
     def count_blanks(self):
         """
@@ -299,9 +293,7 @@ class CardList(list):
 
 
 class Card(_Verify):
-
     length = CARD_LENGTH
-    """The length of a Card image; should always be 80 for valid FITS files."""
 
     # String for a FITS standard compliant (FSC) keyword.
     _keywd_FSC_RE = re.compile(r'^[A-Z0-9_-]{0,%d}$' % KEYWORD_LENGTH)
@@ -327,8 +319,8 @@ class Card(_Verify):
                                  % _digits_NFSC)
 
     # FSC commentary card string which must contain printable ASCII characters.
-    # Note: \Z matches the end of the string without allowing newlines
-    _ascii_text_re = re.compile(r'[ -~]*\Z')
+    _ascii_text = r'[ -~]*$'
+    _comment_FSC_RE = re.compile(_ascii_text)
 
     # Checks for a valid value/comment string.  It returns a match object
     # for a valid value/comment string.
@@ -388,7 +380,7 @@ class Card(_Verify):
     _rvkc_field_specifier_val = (r'(?P<keyword>%s): (?P<val>%s)' %
                                  (_rvkc_field_specifier_s, _numr_FSC))
     _rvkc_keyword_val = r'\'(?P<rawval>%s)\'' % _rvkc_field_specifier_val
-    _rvkc_keyword_val_comm = (r' *%s *(/ *(?P<comm>[ -~]*))?$' %
+    _rvkc_keyword_val_comm = (r' +%s *(/ *(?P<comm>[ -~]*))?$' %
                               _rvkc_keyword_val)
 
     _rvkc_field_specifier_val_RE = re.compile(_rvkc_field_specifier_val + '$')
@@ -405,7 +397,7 @@ class Card(_Verify):
     # (ex "'AXIS.1: 1' / a comment")
     _rvkc_keyword_val_comm_RE = re.compile(_rvkc_keyword_val_comm)
 
-    _commentary_keywords = set(['', 'COMMENT', 'HISTORY', 'END'])
+    _commentary_keywords = ['', 'COMMENT', 'HISTORY', 'END']
 
     # The default value indicator; may be changed if required by a convention
     # (namely HIERARCH cards)
@@ -419,7 +411,7 @@ class Card(_Verify):
         self._keyword = None
         self._value = None
         self._comment = None
-
+        self._rawvalue = None
         self._image = None
 
         # This attribute is set to False when creating the card from a card
@@ -436,13 +428,7 @@ class Card(_Verify):
         self._invalid = False
 
         self._field_specifier = None
-
-        # These are used primarily only by RVKCs
-        self._rawkeyword = None
-        self._rawvalue = None
-
-        if not (keyword is not None and value is not None and
-                self._check_if_rvkc(keyword, value)):
+        if not self._check_if_rvkc(keyword, value):
             # If _check_if_rvkc passes, it will handle setting the keyword and
             # value
             if keyword is not None:
@@ -535,8 +521,6 @@ class Card(_Verify):
 
     @property
     def value(self):
-        """The value associated with the keyword stored in this card."""
-
         if self.field_specifier:
             return float(self._value)
 
@@ -575,51 +559,27 @@ class Card(_Verify):
             raise ValueError(
                 "Floating point %r values are not allowed in FITS headers." %
                 value)
-        elif isinstance(value, unicode):
-            m = self._ascii_text_re.match(value)
-            if not m:
-                raise ValueError(
-                    'FITS header values must contain standard printable ASCII '
-                    'characters; %r contains characters not representable in '
-                    'ASCII or non-printable characters.' % value)
-        elif isinstance(value, bytes):
-            # Allow str, but only if they can be decoded to ASCII text; note
-            # this is not even allowed on Python 3 since the `bytes` type is
-            # not included in `six.string_types`.  Presently we simply don't
-            # allow bytes to be assigned to headers, as doing so would too
-            # easily mask potential user error
-            valid = True
-            try:
-                text_value = value.decode('ascii')
-            except UnicodeDecodeError:
-                valid = False
-            else:
-                # Check against the printable characters regexp as well
-                m = self._ascii_text_re.match(text_value)
-                valid = m is not None
 
-            if not valid:
+        if isinstance(value, unicode):
+            try:
+                # Any string value must be encodable as ASCII
+                value.encode('ascii')
+            except UnicodeEncodeError:
                 raise ValueError(
-                    'FITS header values must contain standard printable ASCII '
-                    'characters; %r contains characters/bytes that do not '
-                    'represent printable characters in ASCII.' % value)
-        elif isinstance(value, np.bool_):
-            value = bool(value)
+                    'FITS header values must contain standard ASCII '
+                    'characters; %r contains characters not representable in '
+                    'ASCII.' % value)
 
         if (pyfits.STRIP_HEADER_WHITESPACE and
             (isinstance(oldvalue, basestring) and
              isinstance(value, basestring))):
             # Ignore extra whitespace when comparing the new value to the old
             different = oldvalue.rstrip() != value.rstrip()
-        elif isinstance(oldvalue, bool) or isinstance(value, bool):
-            different = oldvalue is not value
         else:
-            different = (oldvalue != value or
-                         not isinstance(value, type(oldvalue)))
+            different = oldvalue != value
 
         if different:
             self._value = value
-            self._rawvalue = None
             self._modified = True
             self._valuestring = None
             self._valuemodified = True
@@ -643,35 +603,11 @@ class Card(_Verify):
             raise AttributeError('Values cannot be deleted from record-valued '
                                  'keyword cards')
 
-    @property
-    def rawkeyword(self):
-        """On record-valued keyword cards this is the name of the standard <= 8
-        character FITS keyword that this RVKC is stored in.  Otherwise it is
-        the card's normal keyword.
-        """
-
-        if self._rawkeyword is not None:
-            return self._rawkeyword
-        elif self.field_specifier is not None:
-            self._rawkeyword = self.keyword.split('.', 1)[0]
-            return self._rawkeyword
-        else:
-            return self.keyword
-
     @property
     def rawvalue(self):
-        """On record-valued keyword cards this is the raw string value in
-        the ``<field-specifier>: <value>`` format stored in the card in order
-        to represent a RVKC.  Otherwise it is the card's normal value.
-        """
-
-        if self._rawvalue is not None:
-            return self._rawvalue
-        elif self.field_specifier is not None:
-            self._rawvalue = '%s: %s' % (self.field_specifier, self.value)
-            return self._rawvalue
-        else:
-            return self.value
+        if self._rawvalue is None and self.value:
+            self._rawvalue = self.value
+        return self._rawvalue
 
     @property
     def comment(self):
@@ -697,13 +633,14 @@ class Card(_Verify):
             comment = ''
 
         if isinstance(comment, unicode):
-            m = self._ascii_text_re.match(comment)
-            if not m:
+            try:
+                # Any string value must be encodable as ASCII
+                comment.encode('ascii')
+            except UnicodeEncodeError:
                 raise ValueError(
-                    'FITS header comments must contain standard printable '
-                    'ASCII characters; %r contains characters not '
-                    'representable in ASCII or non-printable characters.' %
-                    comment)
+                    'FITS header comments must contain standard ASCII '
+                    'characters; %r contains characters not representable in '
+                    'ASCII.' % comment)
 
         oldcomment = self._comment
         if oldcomment is None:
@@ -758,11 +695,6 @@ class Card(_Verify):
 
     @property
     def image(self):
-        """
-        The card "image", that is, the 80 byte character string that represents
-        this card in an actual FITS header.
-        """
-
         if self._image and not self._verified:
             self.verify('fix')
         if self._image is None or self._modified:
@@ -805,15 +737,12 @@ class Card(_Verify):
         ----------
         key : or str
             A keyword value or a ``keyword.field-specifier`` value
+
+        Returns
+        -------
+            The converted string
         """
 
-        # Test first for the most common case: a standard FITS keyword provided
-        # in standard all-caps
-        if (len(keyword) <= KEYWORD_LENGTH and
-                cls._keywd_FSC_RE.match(keyword)):
-            return keyword
-
-        # Test if this is a record-valued keyword
         match = cls._rvkc_keyword_name_RE.match(keyword)
 
         if match:
@@ -825,7 +754,6 @@ class Card(_Verify):
             # "HIERARCH HIERARCH", but shame on you if you do that.
             return keyword[9:].strip()
         else:
-            # A normal FITS keyword, but provided in non-standard case
             return keyword.strip().upper()
 
     def _check_if_rvkc(self, *args):
@@ -854,7 +782,22 @@ class Card(_Verify):
             return False
 
         if len(args) == 1:
-            self._check_if_rvkc_image(*args)
+            image = args[0]
+            eq_idx = image.find('=')
+            if eq_idx < 0 or eq_idx > 9:
+                return False
+            keyword, rest = image.split('=', 1)
+            if keyword in self._commentary_keywords:
+                return False
+            match = self._rvkc_keyword_val_comm_RE.match(rest)
+            if match:
+                field_specifier = match.group('keyword')
+                self._keyword = '.'.join((keyword.strip().upper(),
+                                          field_specifier))
+                self._field_specifier = field_specifier
+                self._value = _int_or_float(match.group('val'))
+                self._rawvalue = match.group('rawval')
+                return True
         elif len(args) == 2:
             keyword, value = args
             if not isinstance(keyword, basestring):
@@ -863,91 +806,42 @@ class Card(_Verify):
                 return False
             match = self._rvkc_keyword_name_RE.match(keyword)
             if match and isinstance(value, (int, float)):
-                self._init_rvkc(match.group('keyword'),
-                                match.group('field_specifier'), None, value)
+                field_specifier = match.group('field_specifier')
+                self._keyword = '.'.join((match.group('keyword').upper(),
+                                          field_specifier))
+                self._field_specifier = field_specifier
+                self._value = value
                 return True
-
-            # Testing for ': ' is a quick way to avoid running the full regular
-            # expression, speeding this up for the majority of cases
-            if isinstance(value, basestring) and value.find(': ') > 0:
+            if isinstance(value, basestring):
                 match = self._rvkc_field_specifier_val_RE.match(value)
                 if match and self._keywd_FSC_RE.match(keyword):
-                    self._init_rvkc(keyword, match.group('keyword'), value,
-                                    match.group('val'))
+                    field_specifier = match.group('keyword')
+                    self._keyword = '.'.join((keyword.upper(),
+                                              field_specifier))
+                    self._field_specifier = field_specifier
+                    self._value = _int_or_float(match.group('val'))
+                    self._rawvalue = value
                     return True
 
-    def _check_if_rvkc_image(self, *args):
-        """
-        Implements `Card._check_if_rvkc` for the case of an unparsed card
-        image.  If given one argment this is the full intact image.  If given
-        two arguments the card has already been split between keyword and
-        value+comment at the standard value indicator '= '.
-        """
-
-        if len(args) == 1:
-            image = args[0]
-            eq_idx = image.find(VALUE_INDICATOR)
-            if eq_idx < 0 or eq_idx > 9:
-                return False
-            keyword = image[:eq_idx]
-            rest = image[eq_idx + len(VALUE_INDICATOR):]
-        else:
-            keyword, rest = args
-
-        rest = rest.lstrip()
-
-        # This test allows us to skip running the full regular expression for
-        # the majority of cards that do not contain strings or that definitely
-        # do not contain RVKC field-specifiers; it's very much a
-        # micro-optimization but it does make a measurable difference
-        if not rest or rest[0] != "'" or rest.find(': ') < 2:
-            return False
-
-        match = self._rvkc_keyword_val_comm_RE.match(rest)
-        if match:
-            self._init_rvkc(keyword, match.group('keyword'),
-                            match.group('rawval'), match.group('val'))
-            return True
-
-    def _init_rvkc(self, keyword, field_specifier, field, value):
-        """
-        Sort of addendum to Card.__init__ to set the appropriate internal
-        attributes if the card was determined to be a RVKC.
-        """
-
-        keyword_upper = keyword.upper()
-        self._keyword = '.'.join((keyword_upper, field_specifier))
-        self._rawkeyword = keyword_upper
-        self._field_specifier = field_specifier
-        self._value = _int_or_float(value)
-        self._rawvalue = field
-
     def _parse_keyword(self):
+        if self._check_if_rvkc(self._image):
+            return self._keyword
+
         keyword = self._image[:KEYWORD_LENGTH].strip()
         keyword_upper = keyword.upper()
-        val_ind_idx = self._image.find(VALUE_INDICATOR)
+        value_indicator = self._image.find(VALUE_INDICATOR)
 
-        special = self._commentary_keywords
+        special = self._commentary_keywords + ['CONTINUE']
 
-        if (0 <= val_ind_idx <= KEYWORD_LENGTH or keyword_upper in special or
-                keyword_upper == 'CONTINUE'):
+        if keyword_upper in special or 0 <= value_indicator <= KEYWORD_LENGTH:
             # The value indicator should appear in byte 8, but we are flexible
             # and allow this to be fixed
-            if val_ind_idx >= 0:
-                keyword = keyword[:val_ind_idx]
-                rest = self._image[val_ind_idx + len(VALUE_INDICATOR):]
-
-                # So far this looks like a standard FITS keyword; check whether
-                # the value represents a RVKC; if so then we pass things off to
-                # the RVKC parser
-                if self._check_if_rvkc_image(keyword, rest):
-                    return self._keyword
-
-                keyword_upper = keyword_upper[:val_ind_idx]
+            if value_indicator >= 0:
+                keyword = keyword[:value_indicator]
+                keyword_upper = keyword_upper[:value_indicator]
 
             if keyword_upper != keyword:
                 self._modified = True
-
             return keyword_upper
         elif (keyword_upper == 'HIERARCH' and self._image[8] == ' ' and
               HIERARCH_VALUE_INDICATOR in self._image):
@@ -1068,7 +962,7 @@ class Card(_Verify):
         else:
             image = self.image
 
-        if self.keyword in self._commentary_keywords.union(['CONTINUE']):
+        if self.keyword in self._commentary_keywords + ['CONTINUE']:
             keyword, valuecomment = image.split(' ', 1)
         else:
             try:
@@ -1334,37 +1228,24 @@ class Card(_Verify):
 
         # verify the value, it may be fixable
         keyword, valuecomment = self._split()
-        if self.keyword in self._commentary_keywords:
-            # For commentary keywords all that needs to be ensured is that it
-            # contains only printable ASCII characters
-            if not self._ascii_text_re.match(valuecomment):
-                errs.append(self.run_option(
-                    option,
-                    err_text='Unprintable string %r; commentary cards may '
-                             'only contain printable ASCII characters' %
-                             valuecomment,
-                    fixable=False))
-        else:
-            m = self._value_FSC_RE.match(valuecomment)
-            if not m:
-                errs.append(self.run_option(
-                    option,
-                    err_text='Card %r is not FITS standard (invalid value '
-                             'string: %s).' % (self.keyword, valuecomment),
-                    fix_text=fix_text,
-                    fix=self._fix_value))
+        m = self._value_FSC_RE.match(valuecomment)
+        if not (m or self.keyword in self._commentary_keywords):
+            errs.append(self.run_option(
+                option,
+                err_text='Card %r is not FITS standard (invalid value '
+                         'string: %s).' % (self.keyword, valuecomment),
+                fix_text=fix_text,
+                fix=self._fix_value))
 
         # verify the comment (string), it is never fixable
         m = self._value_NFSC_RE.match(valuecomment)
         if m is not None:
             comment = m.group('comm')
             if comment is not None:
-                if not self._ascii_text_re.match(comment):
+                if not self._comment_FSC_RE.match(comment):
                     errs.append(self.run_option(
                         option,
-                        err_text='Unprintable string %r; header comments may '
-                                 'only contain printable ASCII characters' %
-                                 comment,
+                        err_text='Unprintable string %r' % comment,
                         fixable=False))
 
         return errs
@@ -1395,34 +1276,27 @@ def create_card(key='', value='', comment=''):
     return Card(key, value, comment)
 create_card.__doc__ = Card.__init__.__doc__
 # For API backwards-compatibility
-createCard = deprecated('3.0', name='createCard',
-                        alternative=':meth:`Card.__init__`')(create_card)
 create_card = deprecated('3.1', name='create_card',
-                         alternative='``Card.__init__``',
-                         pending=True)(create_card)
+                         alternative=':meth:`Card.__init__`',
+                         pending=False)(create_card)
 
 
 def create_card_from_string(input):
     return Card.fromstring(input)
 create_card_from_string.__doc__ = Card.fromstring.__doc__
 # For API backwards-compat
-createCardFromString = \
-    deprecated('3.0', name='createCardFromString',
-               alternative=':meth:`Card.fromstring`')(create_card_from_string)
 create_card_from_string = deprecated('3.1', name='create_card_from_string',
                                      alternative=':meth:`Card.fromstring`',
-                                     pending=True)(create_card_from_string)
+                                     pending=False)(create_card_from_string)
 
 
 def upper_key(key):
     return Card.normalize_keyword(key)
 upper_key.__doc__ = Card.normalize_keyword.__doc__
 # For API backwards-compat
-upperKey = deprecated('3.0', name='upperKey',
-                      alternative=':meth:`Card.normalize_keyword`')(upper_key)
 upper_key = deprecated('3.1', name='upper_key',
                        alternative=':meth:`Card.normalize_keyword`',
-                       pending=True)(upper_key)
+                       pending=False)(upper_key)
 
 
 def _int_or_float(s):
@@ -1466,7 +1340,9 @@ def _format_value(value):
         return '%20s' % repr(value)[0]  # T or F
 
     elif _is_int(value):
-        return '%20d' % value
+        # Originally this was '%20d' but Python 2.5 has a bug with string
+        # formatting where this format code won't accept a large 64-bit int
+        return '%20s' % value
 
     elif isinstance(value, (float, np.floating)):
         return '%20s' % _format_float(value)
