@@ -21,7 +21,7 @@ For detailed examples of usage, see the `PyFITS User's Manual
 # The existing unit tests, anyways, only require this in pyfits.hdu.table,
 # but we should still leave new division here too in order to avoid any nasty
 # surprises
-from __future__ import division # confidence high
+from __future__ import division  # confidence high
 
 
 """
@@ -32,6 +32,7 @@ from __future__ import division # confidence high
 
 import os
 import sys
+import urllib
 import warnings
 
 import pyfits.py3compat
@@ -54,7 +55,6 @@ from pyfits.hdu.hdulist import fitsopen as open
 from pyfits.hdu.image import Section
 from pyfits.hdu.table import new_table
 from pyfits.header import Header
-from pyfits.util import deprecated
 
 
 # Additional imports used by the documentation (some of which should be
@@ -65,7 +65,7 @@ from pyfits.verify import VerifyError
 # Set module-global boolean variables--these variables can also get their
 # values from environment variables
 GLOBALS = [
-     # Variable name                       # Default
+    # Variable name                       # Default
     ('ENABLE_RECORD_VALUED_KEYWORD_CARDS', True),
     ('EXTENSION_NAME_CASE_SENSITIVE',      False),
     ('STRIP_HEADER_WHITESPACE',            True),
@@ -84,8 +84,8 @@ __all__ = (pyfits.card.__all__ + pyfits.column.__all__ +
            pyfits.convenience.__all__ + pyfits.diff.__all__ +
            pyfits.hdu.__all__ +
            ['FITS_record', 'FITS_rec', 'open', 'Section', 'new_table',
-            'Header', 'VerifyError', 'TRUE', 'FALSE',
-            'setExtensionNameCaseSensitive'] + [g[0] for g in GLOBALS])
+            'Header', 'VerifyError', 'TRUE', 'FALSE'] +
+           [g[0] for g in GLOBALS])
 
 
 # These are of course deprecated, but a handful of external code still uses
@@ -93,23 +93,11 @@ __all__ = (pyfits.card.__all__ + pyfits.column.__all__ +
 TRUE = True
 FALSE = False
 
-# The following variable and function are used to support case sensitive
-# values for the value of a EXTNAME card in an extension header.  By default,
-# pyfits converts the value of EXTNAME cards to upper case when reading from
-# a file.  By calling setExtensionNameCaseSensitive() the user may circumvent
-# this process so that the EXTNAME value remains in the same case as it is
-# in the file. (Note: The EXTENSION_NAME_CASE_SENSITIVE is now defined above
-# along with the other module variables)
-@deprecated('3.0',
-            alternative='the `pyfits.EXTENSION_NAME_CASE_SENSITIVE` variable')
-def setExtensionNameCaseSensitive(value=True):
-    global EXTENSION_NAME_CASE_SENSITIVE
-    EXTENSION_NAME_CASE_SENSITIVE = value
-
 
 # Warnings routines
 _formatwarning = warnings.formatwarning
 
+
 def formatwarning(message, category, filename, lineno, line=None):
     if issubclass(category, UserWarning):
         return unicode(message) + '\n'
@@ -124,27 +112,22 @@ warnings.formatwarning = formatwarning
 warnings.filterwarnings('always', category=UserWarning, append=True)
 
 
-# This is a workaround for a bug that appears in some versions of Python 2.5
-if sys.version_info[:2] < (2, 6):
-    import urllib
+class ErrorURLopener(urllib.FancyURLopener):
+    """A class to use with `urlretrieve` to allow `IOError` exceptions to be
+    raised when a file specified by a URL cannot be accessed.
 
-    class ErrorURLopener(urllib.FancyURLopener):
-        """A class to use with `urlretrieve` to allow `IOError` exceptions to be
-        raised when a file specified by a URL cannot be accessed.
+    """
 
-        """
+    def http_error_default(self, url, fp, errcode, errmsg, headers):
+        raise IOError((errcode, errmsg, url))
 
-        def http_error_default(self, url, fp, errcode, errmsg, headers):
-            raise IOError((errcode, errmsg, url))
-
-    urllib._urlopener = ErrorURLopener()  # Assign the locally subclassed opener
-                                          # class to the urllibrary
-    urllib._urlopener.tempcache = {}  # Initialize tempcache with an empty
-                                      # dictionary to enable file cacheing
+urllib._urlopener = ErrorURLopener()  # Assign the locally subclassed opener
+                                     # class to the urllibrary
+urllib._urlopener.tempcache = {}  # Initialize tempcache with an empty
+                                 # dictionary to enable file cacheing
 
 
-
-__credits__="""
+__credits__ = """
 
 Copyright (C) 2004 Association of Universities for Research in Astronomy (AURA)
 
