@@ -3,9 +3,10 @@ from pyfits.hdu.compressed import CompImageHDU
 from pyfits.hdu.groups import GroupsHDU, GroupData, Group
 from pyfits.hdu.hdulist import HDUList
 from pyfits.hdu.image import PrimaryHDU, ImageHDU
+from pyfits.hdu.nonstandard import FitsHDU
 from pyfits.hdu.streaming import StreamingHDU
 from pyfits.hdu.table import TableHDU, BinTableHDU
 
 __all__ = ['HDUList', 'PrimaryHDU', 'ImageHDU', 'TableHDU', 'BinTableHDU',
-           'GroupsHDU', 'GroupData', 'Group', 'CompImageHDU', 'StreamingHDU',
-           'register_hdu', 'unregister_hdu', 'DELAYED']
+           'GroupsHDU', 'GroupData', 'Group', 'CompImageHDU', 'FitsHDU',
+           'StreamingHDU', 'register_hdu', 'unregister_hdu', 'DELAYED']
