@@ -35,9 +35,9 @@ class StreamingHDU(object):
         Parameters
         ----------
         name : file path, file object, or file like object
-            The file to which the header and data will be streamed.  If opened,
-            the file object must be opened in a writeable binary mode such as
-            'wb' or 'ab+'.
+            The file to which the header and data will be streamed.
+            If opened, the file object must be opened for append
+            (ab+).
 
         header : `Header` instance
             The header object associated with the data to be written
@@ -117,8 +117,8 @@ class StreamingHDU(object):
         # values to be modified in undesired ways...need to have a better way
         # of doing this
         tmp_hdu._header = self._header
-        self._hdrLoc = tmp_hdu._writeheader(self._ffo)[0]
-        self._datLoc = self._ffo.tell()
+        self._header_offset = tmp_hdu._writeheader(self._ffo)[0]
+        self._data_offset = self._ffo.tell()
         self._size = self.size
 
         if self._size != 0:
@@ -150,21 +150,22 @@ class StreamingHDU(object):
 
         Notes
         -----
-        Only the amount of data specified in the header provided to the class
-        constructor may be written to the stream.  If the provided data would
-        cause the stream to overflow, an `IOError` exception is raised and the
-        data is not written.  Once sufficient data has been written to the
-        stream to satisfy the amount specified in the header, the stream is
-        padded to fill a complete FITS block and no more data will be accepted.
-        An attempt to write more data after the stream has been filled will
-        raise an `IOError` exception.  If the dtype of the input data does not
-        match what is expected by the header, a `TypeError` exception is
-        raised.
+        Only the amount of data specified in the header provided to
+        the class constructor may be written to the stream.  If the
+        provided data would cause the stream to overflow, an `IOError`
+        exception is raised and the data is not written.  Once
+        sufficient data has been written to the stream to satisfy the
+        amount specified in the header, the stream is padded to fill a
+        complete FITS block and no more data will be accepted.  An
+        attempt to write more data after the stream has been filled
+        will raise an `IOError` exception.  If the dtype of the input
+        data does not match what is expected by the header, a
+        `TypeError` exception is raised.
         """
 
-        curDataSize = self._ffo.tell() - self._datLoc
+        size = self._ffo.tell() - self._data_offset
 
-        if self.writecomplete or curDataSize + data.nbytes > self._size:
+        if self.writecomplete or size + data.nbytes > self._size:
             raise IOError('Attempt to write more data to the stream than the '
                           'header specified.')
 
@@ -182,7 +183,7 @@ class StreamingHDU(object):
 
         self._ffo.writearray(output)
 
-        if self._ffo.tell() - self._datLoc == self._size:
+        if self._ffo.tell() - self._data_offset == self._size:
 #
 #           the stream is full so pad the data to the next FITS block
 #
