@@ -1,4 +1,4 @@
-from __future__ import division # confidence high
+from __future__ import division
 
 import sys
 
